<?xml version="1.0" ?>
<xsl:stylesheet 
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
        xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
        exclude-result-prefixes="wsdl" 
        xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
        xmlns:wev-ext="ext1" 
        extension-element-prefixes="redirect wev-ext" version="1.0">

  <!-- 
   Capture all operation names in a space separated list 
   sorted alphabetically.
  -->
  <xsl:variable name="opnames">
    <xsl:for-each select="document(/wsdlfilelist/entry/@filename)/wsdl:definitions/wsdl:portType/wsdl:operation">
      <xsl:sort select="@name"/>
      <xsl:value-of select="@name"/>
      <xsl:text> </xsl:text>
    </xsl:for-each>
  </xsl:variable>

  <!-- 
   Capture all definitions names in a space separated list 
   sorted alphabetically by operation name.
  -->
  <xsl:variable name="dfnames">
    <xsl:for-each select="document(/wsdlfilelist/entry/@filename)/wsdl:definitions/wsdl:portType/wsdl:operation">
      <xsl:sort select="@name"/>
      <xsl:value-of select="../../@name"/>
      <xsl:text> </xsl:text>
    </xsl:for-each>
  </xsl:variable>

  <xsl:template name="buildOperationIndex">
  <redirect:write select="concat($outputDir,'operation-index.html')">
    <HTML>
    <HEAD>
    <xsl:comment>Generated by wsdldoc on <xsl:value-of select="wev-ext:getDate()" /></xsl:comment>
    <TITLE>
      <xsl:text>Operation Index</xsl:text>
    </TITLE>
    <LINK REL="stylesheet" TYPE="text/css" HREF="stylesheet.css" TITLE="Style"></LINK>
    </HEAD>
    <BODY BGCOLOR="white">
    <xsl:call-template name="topNavbar">
      <xsl:with-param name="pageType" select="'index'"/>
      <xsl:with-param name="label" select="'Operation Index'"/>
    </xsl:call-template>
    <A HREF="#_A_">A</A><xsl:text> </xsl:text>
    <A HREF="#_B_">B</A><xsl:text> </xsl:text> 
    <A HREF="#_C_">C</A><xsl:text> </xsl:text> 
    <A HREF="#_D_">D</A><xsl:text> </xsl:text> 
    <A HREF="#_E_">E</A><xsl:text> </xsl:text> 
    <A HREF="#_F_">F</A><xsl:text> </xsl:text> 
    <A HREF="#_G_">G</A><xsl:text> </xsl:text> 
    <A HREF="#_H_">H</A><xsl:text> </xsl:text> 
    <A HREF="#_I_">I</A><xsl:text> </xsl:text> 
    <A HREF="#_J_">J</A><xsl:text> </xsl:text> 
    <A HREF="#_K_">K</A><xsl:text> </xsl:text> 
    <A HREF="#_L_">L</A><xsl:text> </xsl:text> 
    <A HREF="#_M_">M</A><xsl:text> </xsl:text> 
    <A HREF="#_N_">N</A><xsl:text> </xsl:text> 
    <A HREF="#_O_">O</A><xsl:text> </xsl:text> 
    <A HREF="#_P_">P</A><xsl:text> </xsl:text> 
    <A HREF="#_Q_">Q</A><xsl:text> </xsl:text> 
    <A HREF="#_R_">R</A><xsl:text> </xsl:text> 
    <A HREF="#_S_">S</A><xsl:text> </xsl:text> 
    <A HREF="#_T_">T</A><xsl:text> </xsl:text> 
    <A HREF="#_U_">U</A><xsl:text> </xsl:text> 
    <A HREF="#_V_">V</A><xsl:text> </xsl:text> 
    <A HREF="#_W_">W</A><xsl:text> </xsl:text> 
    <A HREF="#_X_">X</A><xsl:text> </xsl:text> 
    <A HREF="#_Y_">Y</A><xsl:text> </xsl:text> 
    <A HREF="#_Z_">Z</A><xsl:text> </xsl:text> 
    <A HREF="#___">_</A> 
    <HR />
    <xsl:call-template name="processOperations">
      <xsl:with-param name="ops" select="$opnames"/>
      <xsl:with-param name="dfs" select="$dfnames"/>
      <xsl:with-param name="prev" select="''"/>
    </xsl:call-template>
    <xsl:call-template name="botNavbar">
      <xsl:with-param name="pageType" select="'index'"/>
      <xsl:with-param name="label" select="'Operation Index'"/>
    </xsl:call-template>
    </BODY>
    </HTML>
  </redirect:write>
  </xsl:template>

  <xsl:template name="processOperations">
    <xsl:param name="ops"/>
    <xsl:param name="dfs"/>
    <xsl:param name="prev"/>

    <xsl:choose>
      <xsl:when test="not(string-length(normalize-space($ops)))">
        <!-- LIST EMPTY TERMINATE RECURSION -->
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="curnm" select="substring-before($ops, ' ')"/>
        <xsl:variable name="curdf" select="substring-before($dfs, ' ')"/>
        <xsl:variable name="remainder" select="substring-after($ops, ' ')"/>
        <xsl:variable name="remdf" select="substring-after($dfs, ' ')"/>
        <xsl:variable name="curop"
          select="document(/wsdlfilelist/entry/@filename)/wsdl:definitions[@name=$curdf]/wsdl:portType/wsdl:operation[@name=$curnm]"/>
        <xsl:variable name="inmsgname">
          <xsl:call-template name="makeLocal">
            <xsl:with-param name="qname" select="$curop/wsdl:input/@message"/>
          </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="inmsg" 
          select="document(/wsdlfilelist/entry/@filename)/wsdl:definitions[@name=$curdf]/wsdl:message[@name=$inmsgname]"/>

        <xsl:variable name="fc"  select="translate(substring($curnm,1,1),
                                                   'abcdefghijklmnopqrstuvwxyz',
                                                   'ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/>
        <xsl:variable name="pfc" select="translate(substring($prev,1,1),
                                                   'abcdefghijklmnopqrstuvwxyz',
                                                   'ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/>
        <!-- NEED TO CONDITIONALLY OUTPUT A SECTION HEADING -->
        <xsl:if test="not($fc=$pfc)">
          <A NAME="{concat('_', $fc, '_')}"></A>
          <H2>
            <xsl:value-of select="$fc"/>
          </H2>
        </xsl:if>
        <xsl:call-template name="formatOperation">
          <xsl:with-param name="operation" select="$curop"/>
          <xsl:with-param name="inputmsg"  select="$inmsg"/>
        </xsl:call-template>
        <xsl:call-template name="processOperations">
          <xsl:with-param name="ops" select="$remainder"/>
          <xsl:with-param name="dfs" select="$remdf"/>
          <xsl:with-param name="prev" select="$curnm"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="formatOperation">
    <xsl:param name="operation"/>
    <xsl:param name="inputmsg"/>

    <xsl:variable name="sig">
      <xsl:call-template name="makeSignature">
        <xsl:with-param name="operation" select="$operation"/>
        <xsl:with-param name="inputmsg" select="$inputmsg"/>
      </xsl:call-template>
    </xsl:variable>

    <A HREF="{concat($operation/../../@name,'/',$operation/../@name,'-porttype.html#',$sig)}">
      <xsl:value-of select="$operation/@name"/>
    </A><B><xsl:text> from portType </xsl:text></B>
    <A HREF="{concat($operation/../../@name,'/',$operation/../@name,'-porttype.html')}">
      <xsl:value-of select="$operation/../@name"/>
    </A><B><xsl:text> from definitions </xsl:text></B>
    <A HREF="{concat($operation/../../@name,'/definitions-summary.html')}">
      <xsl:value-of select="$operation/../../@name"/>
    </A>
    <BR />
  </xsl:template>


  <xsl:template name="output-index">
  </xsl:template>

</xsl:stylesheet>
