<?xml version="1.0" ?>
<xsl:stylesheet 
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
        xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
        exclude-result-prefixes="wsdl" 
        xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
        xmlns:wev-ext="ext1" 
        extension-element-prefixes="redirect wev-ext" version="1.0">

  <!-- 
    Capture all filename attributes in a space separated list.
  -->
  <xsl:variable name="files">
    <xsl:for-each select="/wsdlfilelist/entry">
       <xsl:value-of select="@filename"/>
      <xsl:text>*</xsl:text>
    </xsl:for-each>
  </xsl:variable>
  <!-- 
    Capture all binding elements names in a space separated list.
  -->
  <xsl:variable name="bindings">
    <xsl:call-template name="getBindingList">
      <xsl:with-param name="flist" select="$files"/>
    </xsl:call-template>
  </xsl:variable>

  <xsl:template name="getBindingList">
    <xsl:param name="flist"/>

    <xsl:choose>
      <xsl:when test="not(string-length(normalize-space($flist)))">
        <!-- LIST EMPTY TERMINATE RECURSION -->
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="head">
          <xsl:value-of select="substring-before($flist, '*')"/>
        </xsl:variable>
        <xsl:variable name="remainder">
         <xsl:value-of select="substring-after($flist, '*')"/>
        </xsl:variable>
        <xsl:call-template name="getBindingNamesForFile">
          <xsl:with-param name="nm" select="$head"/>
        </xsl:call-template>
        <xsl:call-template name="getBindingList">
          <xsl:with-param name="flist" select="$remainder"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="getBindingNamesForFile">
    <xsl:param name="nm"/>

    <xsl:variable name="fname">
      <xsl:call-template name="filenameFix">
        <xsl:with-param name="wsdlFileName" select="$nm"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="sn">
      <xsl:call-template name="makeShortName">
        <xsl:with-param name="name" select="$fname"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:for-each select="document($nm)/wsdl:definitions/wsdl:binding">
      <xsl:value-of select="@name"/><xsl:text>:</xsl:text><xsl:value-of select="$sn"/>
      <xsl:text>*</xsl:text>
    </xsl:for-each>
  </xsl:template>

  <!-- 
    Capture all message elements names in a space separated list.
  -->
  <xsl:variable name="messages">
    <xsl:call-template name="getMessageList">
      <xsl:with-param name="flist" select="$files"/>
    </xsl:call-template>
  </xsl:variable>

  <xsl:template name="getMessageList">
    <xsl:param name="flist"/>

    <xsl:choose>
      <xsl:when test="not(string-length(normalize-space($flist)))">
        <!-- LIST EMPTY TERMINATE RECURSION -->
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="head">
          <xsl:value-of select="substring-before($flist, '*')"/>
        </xsl:variable>
        <xsl:variable name="remainder">
         <xsl:value-of select="substring-after($flist, '*')"/>
        </xsl:variable>
        <xsl:call-template name="getMessageNamesForFile">
          <xsl:with-param name="nm" select="$head"/>
        </xsl:call-template>
        <xsl:call-template name="getMessageList">
          <xsl:with-param name="flist" select="$remainder"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="getMessageNamesForFile">
    <xsl:param name="nm"/>

    <xsl:variable name="fname">
      <xsl:call-template name="filenameFix">
        <xsl:with-param name="wsdlFileName" select="$nm"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="sn">
      <xsl:call-template name="makeShortName">
        <xsl:with-param name="name" select="$fname"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:for-each select="document($nm)/wsdl:definitions/wsdl:message">
      <xsl:value-of select="@name"/><xsl:text>:</xsl:text><xsl:value-of select="$sn"/>
      <xsl:text>*</xsl:text>
    </xsl:for-each>
  </xsl:template>

  <!-- 
    Capture all porttype elements names in a space separated list.
  -->
  <xsl:variable name="porttypes">
    <xsl:call-template name="getPortTypeList">
      <xsl:with-param name="flist" select="$files"/>
    </xsl:call-template>
  </xsl:variable>

  <xsl:template name="getPortTypeList">
    <xsl:param name="flist"/>

    <xsl:choose>
      <xsl:when test="not(string-length(normalize-space($flist)))">
        <!-- LIST EMPTY TERMINATE RECURSION -->
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="head">
          <xsl:value-of select="substring-before($flist, '*')"/>
        </xsl:variable>
        <xsl:variable name="remainder">
         <xsl:value-of select="substring-after($flist, '*')"/>
        </xsl:variable>
        <xsl:call-template name="getPortTypeNamesForFile">
          <xsl:with-param name="nm" select="$head"/>
        </xsl:call-template>
        <xsl:call-template name="getPortTypeList">
          <xsl:with-param name="flist" select="$remainder"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="getPortTypeNamesForFile">
    <xsl:param name="nm"/>

    <xsl:variable name="fname">
      <xsl:call-template name="filenameFix">
        <xsl:with-param name="wsdlFileName" select="$nm"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="sn">
      <xsl:call-template name="makeShortName">
        <xsl:with-param name="name" select="$fname"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:for-each select="document($nm)/wsdl:definitions/wsdl:portType">
      <xsl:value-of select="@name"/><xsl:text>:</xsl:text><xsl:value-of select="$sn"/>
      <xsl:text>*</xsl:text>
    </xsl:for-each>
  </xsl:template>

  <!-- 
    Capture all service elements names in a space separated list.
  -->
  <xsl:variable name="services">
    <xsl:call-template name="getServiceList">
      <xsl:with-param name="flist" select="$files"/>
    </xsl:call-template>
  </xsl:variable>

  <xsl:template name="getServiceList">
    <xsl:param name="flist"/>

    <xsl:choose>
      <xsl:when test="not(string-length(normalize-space($flist)))">
        <!-- LIST EMPTY TERMINATE RECURSION -->
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="head">
          <xsl:value-of select="substring-before($flist, '*')"/>
        </xsl:variable>
        <xsl:variable name="remainder">
         <xsl:value-of select="substring-after($flist, '*')"/>
        </xsl:variable>
        <xsl:call-template name="getServiceNamesForFile">
          <xsl:with-param name="nm" select="$head"/>
        </xsl:call-template>
        <xsl:call-template name="getServiceList">
          <xsl:with-param name="flist" select="$remainder"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="getServiceNamesForFile">
    <xsl:param name="nm"/>

    <xsl:variable name="fname">
      <xsl:call-template name="filenameFix">
        <xsl:with-param name="wsdlFileName" select="$nm"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="sn">
      <xsl:call-template name="makeShortName">
        <xsl:with-param name="name" select="$fname"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:for-each select="document($nm)/wsdl:definitions/wsdl:service">
      <xsl:value-of select="@name"/><xsl:text>:</xsl:text><xsl:value-of select="$sn"/>
      <xsl:text>*</xsl:text>
    </xsl:for-each>
  </xsl:template>

  <!-- 
    Capture all types elements names in a space separated list.
  -->
  <xsl:variable name="typs">
    <xsl:call-template name="getTypesList">
      <xsl:with-param name="flist" select="$files"/>
    </xsl:call-template>
  </xsl:variable>

  <xsl:template name="getTypesList">
    <xsl:param name="flist"/>

    <xsl:choose>
      <xsl:when test="not(string-length(normalize-space($flist)))">
        <!-- LIST EMPTY TERMINATE RECURSION -->
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="head">
          <xsl:value-of select="substring-before($flist, '*')"/>
        </xsl:variable>
        <xsl:variable name="remainder">
         <xsl:value-of select="substring-after($flist, '*')"/>
        </xsl:variable>
        <xsl:call-template name="getTypesNamesForFile">
          <xsl:with-param name="nm" select="$head"/>
        </xsl:call-template>
        <xsl:call-template name="getTypesList">
          <xsl:with-param name="flist" select="$remainder"/>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="getTypesNamesForFile">
    <xsl:param name="nm"/>
    
    <xsl:variable name="fname">
      <xsl:call-template name="filenameFix">
        <xsl:with-param name="wsdlFileName" select="$nm"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="sn">
      <xsl:call-template name="makeShortName">
        <xsl:with-param name="name" select="$fname"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:for-each select="document($nm)/wsdl:definitions/wsdl:types">
      <xsl:value-of select="$sn"/><xsl:text>:</xsl:text><xsl:value-of select="$sn"/>
      <xsl:text>*</xsl:text>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="formatSubelement">
    <xsl:param name="nm"/>
    <xsl:param name="tp"/>

    <xsl:variable name="enm">
      <xsl:value-of select="substring-before($nm, ':')"/>
    </xsl:variable>
    <xsl:variable name="dnm">
      <xsl:value-of select="substring-after($nm, ':')"/>
    </xsl:variable>

      <BR />
      <A HREF="{concat($dnm,'/',$enm,'-',$tp,'.html')}" TARGET="detailFrame">
        <xsl:value-of select="$enm"/>
      </A>
  </xsl:template>

  <xsl:template name="processNameString">
    <xsl:param name="list"/>
    <xsl:param name="ltyp"/>

    <xsl:choose>
      <xsl:when test="not(string-length(normalize-space($list)))">
        <!-- LIST EMPTY TERMINATE RECURSION -->
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="head">
          <xsl:copy-of select="substring-before($list, '*')"/>
        </xsl:variable>
        <xsl:variable name="remainder">
         <xsl:copy-of select="substring-after($list, '*')"/>
        </xsl:variable>
        <xsl:call-template name="formatSubelement">
          <xsl:with-param name="nm"><xsl:copy-of select="$head"/>
          </xsl:with-param>
          <xsl:with-param name="tp"><xsl:copy-of select="$ltyp"/>
          </xsl:with-param>
        </xsl:call-template>
        <xsl:call-template name="processNameString">
          <xsl:with-param name="list"><xsl:copy-of select="$remainder"/>
          </xsl:with-param>
          <xsl:with-param name="ltyp"><xsl:copy-of select="$ltyp"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="buildSubelementList">
  <redirect:write select="concat($outputDir,'subelement-list.html')">
    <HTML>
    <HEAD>
    <xsl:comment>Generated by wsdldoc on <xsl:value-of select="wev-ext:getDate()" /></xsl:comment>
    <TITLE>
      <xsl:text>Definition Elements</xsl:text>
    </TITLE>
    <LINK REL="stylesheet" TYPE="text/css" HREF="stylesheet.css" TITLE="Style"></LINK>
    </HEAD>
    <BODY BGCOLOR="white">
    <FONT size="+1" CLASS="FrameHeadingFont"><B>Definition Elements</B></FONT>
    <xsl:if test="string-length(normalize-space($typs))">
      <TABLE BORDER="0" WIDTH="100%">
      <TR>
      <TD><FONT size="+1" CLASS="FrameHeadingFont">
      Types</FONT>
      <FONT CLASS="FrameItemFont">
      <xsl:call-template name="processNameString">
        <xsl:with-param name="list" select="$typs"/>
        <xsl:with-param name="ltyp" select="'types'"/>
      </xsl:call-template>
      </FONT>
      </TD>
      </TR>
      </TABLE>
    </xsl:if>
    <xsl:if test="string-length(normalize-space($messages))">
      <TABLE BORDER="0" WIDTH="100%">
      <TR>
      <TD><FONT size="+1" CLASS="FrameHeadingFont">
      Messages</FONT>
      <FONT CLASS="FrameItemFont">
      <xsl:call-template name="processNameString">
        <xsl:with-param name="list" select="$messages"/>
        <xsl:with-param name="ltyp" select="'message'"/>
      </xsl:call-template>
      </FONT>
      </TD>
      </TR>
      </TABLE>
    </xsl:if>
    <xsl:if test="string-length(normalize-space($porttypes))">
      <TABLE BORDER="0" WIDTH="100%">
      <TR>
      <TD><FONT size="+1" CLASS="FrameHeadingFont">
      PortTypes</FONT>
      <FONT CLASS="FrameItemFont">
      <xsl:call-template name="processNameString">
        <xsl:with-param name="list" select="$porttypes"/>
        <xsl:with-param name="ltyp" select="'porttype'"/>
      </xsl:call-template>
      </FONT>
      </TD>
      </TR>
      </TABLE>
    </xsl:if>
    <xsl:if test="string-length(normalize-space($bindings))">
      <TABLE BORDER="0" WIDTH="100%">
      <TR>
      <TD><FONT size="+1" CLASS="FrameHeadingFont">
      Bindings</FONT>
      <FONT CLASS="FrameItemFont">
      <xsl:call-template name="processNameString">
        <xsl:with-param name="list" select="$bindings"/>
        <xsl:with-param name="ltyp" select="'binding'"/>
      </xsl:call-template>
      </FONT>
      </TD>
      </TR>
      </TABLE>
    </xsl:if>
    <xsl:if test="string-length(normalize-space($services))">
      <TABLE BORDER="0" WIDTH="100%">
      <TR>
      <TD><FONT size="+1" CLASS="FrameHeadingFont">
      Services</FONT>
      <FONT CLASS="FrameItemFont">
      <xsl:call-template name="processNameString">
        <xsl:with-param name="list" select="$services"/>
        <xsl:with-param name="ltyp" select="'service'"/>
      </xsl:call-template>
      </FONT>
      </TD>
      </TR>
      </TABLE>
    </xsl:if>
    </BODY>
    </HTML>
  </redirect:write>
  </xsl:template>

</xsl:stylesheet>
