<?xml version="1.0" ?>
<xsl:stylesheet 
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
        xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
        exclude-result-prefixes="wsdl" 
        xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
        xmlns:wev-ext="ext1" 
        extension-element-prefixes="redirect wev-ext" 
        version="1.0">

  <xsl:template match="wsdl:definitions" mode="summary">
    <xsl:param name="file"/>

    <xsl:variable name="fname">
      <xsl:call-template name="filenameFix">
        <xsl:with-param name="wsdlFileName" select="$file"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="fnwosfx">
      <xsl:value-of select="substring-before($fname, '.wsdl')"/>
    </xsl:variable>

    <!--
    <xsl:message><xsl:text>Generating definitions summary for </xsl:text>
      <xsl:value-of select="$fnwosfx"/><xsl:text>...</xsl:text>
    </xsl:message>
    -->

  <redirect:write select="concat($outputDir,$fnwosfx,'/definitions-summary.html')">
    <HTML>
    <HEAD>
    <xsl:comment>Generated by wsdldoc on <xsl:value-of select="wev-ext:getDate()" /></xsl:comment>
    <TITLE>
      <xsl:text>Overview</xsl:text>
    </TITLE>
    <LINK REL="stylesheet" TYPE="text/css" HREF="../stylesheet.css" TITLE="Style"></LINK>
    </HEAD>
    <BODY BGCOLOR="white">
    <xsl:call-template name="topNavbar">
      <xsl:with-param name="pageType" select="'definitions'"/>
      <xsl:with-param name="label" select="$fnwosfx"/>
    </xsl:call-template>
    <H2>
      <xsl:text>Definitions for </xsl:text><xsl:value-of select="$fnwosfx"/>
    </H2>
    <xsl:call-template name="firstSentence">
      <xsl:with-param name="el" select="current()"/>
    </xsl:call-template>
    <P></P>
    <B>See: </B>
    <BR />
    <A HREF="#definitions_description"><B>Description</B></A>
    <P></P>
    <!-- CREATE A TABLE FOR EACH TOP LEVEL ELEMENT TYPE -->
    <xsl:if test="wsdl:types">
      <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
      <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
      <TD COLSPAN="2"><FONT SIZE="+2">
      <B>Types Summary</B></FONT>
      </TD>
      </TR>
      <xsl:for-each select="wsdl:types">

        <TR BGCOLOR="white" CLASS="TableRowColor">
        <TD WIDTH="15%">
        <B><A HREF="{concat($fnwosfx,'-types.html')}"><xsl:value-of select="$fnwosfx"/>
        <xsl:text>Types</xsl:text></A></B>
        </TD>
        <TD>
        <xsl:call-template name="firstSentence">
          <xsl:with-param name="el" select="."/>
        </xsl:call-template>
        </TD>
        </TR>
      </xsl:for-each>
      </TABLE>
      <P></P>
    </xsl:if>
    <xsl:if test="wsdl:message">
      <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
      <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
      <TD COLSPAN="2"><FONT SIZE="+2">
      <B>Message Summary</B></FONT>
      </TD>
      </TR>
      <xsl:for-each select="wsdl:message">
        <xsl:sort select="@name"/>

        <TR BGCOLOR="white" CLASS="TableRowColor">
        <TD WIDTH="15%">
        <B><A HREF="{concat(@name,'-message.html')}"><xsl:value-of select="@name"/>
        </A></B>
        </TD>
        <TD>
        <xsl:call-template name="firstSentence">
          <xsl:with-param name="el" select="."/>
        </xsl:call-template>
        </TD>
        </TR>
      </xsl:for-each>
      </TABLE>
      <P></P>
    </xsl:if>
    <xsl:if test="wsdl:portType">
      <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
      <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
      <TD COLSPAN="2"><FONT SIZE="+2">
      <B>PortType Summary</B></FONT>
      </TD>
      </TR>
      <xsl:for-each select="wsdl:portType">
        <xsl:sort select="@name"/>

        <TR BGCOLOR="white" CLASS="TableRowColor">
        <TD WIDTH="15%">
        <B><A HREF="{concat(@name,'-porttype.html')}"><xsl:value-of select="@name"/>
        </A></B>
        </TD>
        <TD>
        <xsl:call-template name="firstSentence">
          <xsl:with-param name="el" select="."/>
        </xsl:call-template>
        </TD>
        </TR>
      </xsl:for-each>
      </TABLE>
      <P></P>
    </xsl:if>
    <xsl:if test="wsdl:binding">
      <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
      <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
      <TD COLSPAN="2"><FONT SIZE="+2">
      <B>Binding Summary</B></FONT>
      </TD>
      </TR>
      <xsl:for-each select="wsdl:binding">
        <xsl:sort select="@name"/>

        <TR BGCOLOR="white" CLASS="TableRowColor">
        <TD WIDTH="15%">
        <B><A HREF="{concat(@name,'-binding.html')}"><xsl:value-of select="@name"/>
        </A></B>
        </TD>
        <TD>
        <xsl:call-template name="firstSentence">
          <xsl:with-param name="el" select="."/>
        </xsl:call-template>
        </TD>
        </TR>
      </xsl:for-each>
      </TABLE>
      <P></P>
    </xsl:if>
    <xsl:if test="wsdl:service">
      <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
      <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
      <TD COLSPAN="2"><FONT SIZE="+2">
      <B>Service Summary</B></FONT>
      </TD>
      </TR>
      <xsl:for-each select="wsdl:service">
        <xsl:sort select="@name"/>

        <TR BGCOLOR="white" CLASS="TableRowColor">
        <TD WIDTH="15%">
        <B><A HREF="{concat(@name,'-service.html')}"><xsl:value-of select="@name"/>
        </A></B>
        </TD>
        <TD>
        <xsl:call-template name="firstSentence">
          <xsl:with-param name="el" select="."/>
        </xsl:call-template>
        </TD>
        </TR>
      </xsl:for-each>
      </TABLE>
    </xsl:if>
    <P></P>
    <A NAME="definitions_description"><!-- --></A>
    <H2>
      <xsl:text>Definitions for </xsl:text><xsl:value-of select="@name"/>
    </H2>
    <P></P>
    <xsl:call-template name="getDocumentation">
      <xsl:with-param name="el" select="current()"/>
    </xsl:call-template>
    <xsl:call-template name="botNavbar">
      <xsl:with-param name="pageType" select="'definitions'"/>
      <xsl:with-param name="label" select="@name"/>
    </xsl:call-template>
    </BODY>
    </HTML>
  </redirect:write>
  </xsl:template>

</xsl:stylesheet>
