<?xml version="1.0" ?>
<xsl:stylesheet 
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
        xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
        xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/" 
        xmlns:http="http://schemas.xmlsoap.org/wsdl/http/"
        exclude-result-prefixes="wsdl soap" 
        xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
        xmlns:wev-ext="ext1" 
        extension-element-prefixes="redirect wev-ext" 
        version="1.0">

  <xsl:template match="wsdl:binding">
    <xsl:param name="file"/>
  
    <xsl:variable name="fname">
      <xsl:call-template name="filenameFix">
        <xsl:with-param name="wsdlFileName" select="$file"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="fnwosfx">
      <xsl:value-of select="substring-before($fname, '.wsdl')"/>
    </xsl:variable>

    <xsl:variable name="ptq">
      <xsl:call-template name="makeLocal">
        <xsl:with-param name="qname" select="@type"/>
      </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="pt" select="../wsdl:portType[@name=$ptq]"/>

  <redirect:write select="concat($outputDir,$fnwosfx,'/',@name,'-binding.html')">
    <HTML>
    <HEAD>
    <xsl:comment>Generated by wsdldoc on <xsl:value-of select="wev-ext:getDate()" /></xsl:comment>
    <TITLE>
      <xsl:value-of select="@name" />
    </TITLE>
    <LINK REL="stylesheet" TYPE="text/css" HREF="../stylesheet.css" TITLE="Style"></LINK>
    </HEAD>
    <BODY BGCOLOR="white">
    <xsl:call-template name="topNavbar">
      <xsl:with-param name="pageType" select="'binding'"/>
      <xsl:with-param name="label" select="$fnwosfx"/>
    </xsl:call-template>

    <xsl:comment> ======== START OF BINDING DATA ======== </xsl:comment>
    <H2>
    <FONT SIZE="-1">
      <xsl:value-of select="$fnwosfx" />
    </FONT>
    <BR />
      <xsl:text>Binding </xsl:text>
      <xsl:value-of select="@name"/>
    </H2>
    <DL>
    <DT>
    <B>
      <xsl:text>Bound PortType:</xsl:text>
    </B>
    </DT>
    <DD>
      <P></P>
      <A HREF="{concat($pt/@name, '-porttype.html')}">
      <xsl:value-of select="$pt/@name"/>
      </A>
      <P></P>
    </DD>
    <DT>
    <B>
      <xsl:text>Bound Protocol: </xsl:text>
    </B>
    <xsl:choose>
      <xsl:when test="soap:binding">
        <xsl:text>SOAP</xsl:text>
      </xsl:when>
      <xsl:when test="http:binding">
        <xsl:text>HTTP</xsl:text>
      </xsl:when>
    </xsl:choose>
    </DT>
    <DD>
    <xsl:choose>
      <xsl:when test="soap:binding">
        <P></P>
        <B><xsl:text>Style: </xsl:text></B><xsl:value-of select="soap:binding/@style"/>
        <BR />
        <B><xsl:text>Transport: </xsl:text></B><xsl:value-of select="soap:binding/@transport"/>
      </xsl:when>
      <xsl:when test="http:binding">
        <P></P>
        <B><xsl:text>Verb: </xsl:text></B><xsl:value-of select="http:binding/@verb"/>
      </xsl:when>
    </xsl:choose>
    </DD>
    </DL>
    <HR />
    <DL>
    <DT>
      <xsl:text>Binding </xsl:text>
    <B>
      <xsl:value-of select="@name"/>
    </B>
    </DT>
    <DD>
    <P></P>
    <xsl:call-template name="getDocumentation">
      <xsl:with-param name="el" select="current()"/>
    </xsl:call-template>
    </DD>
    </DL>
    <P></P>
    <HR />
    <P></P>
    <xsl:comment> ========== OPERATION SUMMARY =========== </xsl:comment>
    <A NAME="binding_summary"> <!-- --></A>
    <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
    <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
    <TD COLSPAN="2">
    <FONT SIZE="+2">
    <B>
      <xsl:text>Operation Summary</xsl:text>
    </B>
    </FONT>
    </TD>
    </TR>
      <xsl:apply-templates select="wsdl:operation" mode="binding-summary"/>
    </TABLE>
    <P></P>
    <xsl:comment> ============ OPERATION DETAIL ========== </xsl:comment>
    <A NAME="binding_detail"> <!-- --></A>
    <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
    <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
    <TD COLSPAN="1">
    <FONT SIZE="+2">
    <B>
      <xsl:text>Operation Detail</xsl:text>
    </B>
    </FONT>
    </TD>
    </TR>
    </TABLE>
      <xsl:apply-templates select="wsdl:operation" mode="binding-detail"/>
    <HR />
    <xsl:comment> ========= END OF PORTTYPE DATA ========= </xsl:comment>

    <xsl:call-template name="botNavbar">
      <xsl:with-param name="pageType" select="'binding'"/>
      <xsl:with-param name="label" select="$fnwosfx"/>
    </xsl:call-template>
    </BODY>
    </HTML>
  </redirect:write>
  </xsl:template>

  <xsl:template match="wsdl:operation" mode="binding-summary">
        <xsl:variable name="operationName" select="@name" />

    <TR BGCOLOR="white" CLASS="TableRowColor">
    <TD ALIGN="right" VALIGN="top" WIDTH="15%">
      <A HREF="{concat('#',generate-id())}">
        <xsl:value-of select="$operationName"/>
      </A>
    </TD>
    <TD>
      <xsl:call-template name="firstSentence">
        <xsl:with-param name="el" select="current()"/>
      </xsl:call-template>
    </TD>
    </TR>
  </xsl:template>

  <xsl:template match="wsdl:operation" mode="binding-detail">
        <xsl:variable name="operationName" select="@name" />

    <A NAME="{generate-id()}"> <!-- --></A>
    <H3>
      <xsl:value-of select="$operationName" />
    </H3>
    <DL>
    <DD>
      <xsl:choose>
        <xsl:when test="soap:operation">
          <B>Soap Action: </B>
          <xsl:value-of select="soap:operation/@soapAction"/>
        </xsl:when>
        <xsl:when test="http:operation">
          <B>Http Location: </B>
          <xsl:value-of select="http:operation/@location"/>
        </xsl:when>
      </xsl:choose>
    </DD>
    <P></P>
    <DD>
    <xsl:call-template name="getDocumentation">
      <xsl:with-param name="el" select="current()"/>
    </xsl:call-template>
    </DD>
    </DL>
    <HR />
  </xsl:template>

</xsl:stylesheet>
