<?xml version="1.0" ?>
<xsl:stylesheet 
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
        xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
        exclude-result-prefixes="wsdl" 
        xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
        xmlns:wev-ext="ext1" 
        extension-element-prefixes="redirect wev-ext" 
        version="1.0">

  <xsl:template match="wsdl:message">
    <xsl:param name="file"/>
    
    <xsl:variable name="fname">
      <xsl:call-template name="filenameFix">
        <xsl:with-param name="wsdlFileName" select="$file"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="fnwosfx">
      <xsl:value-of select="substring-before($fname, '.wsdl')"/>
    </xsl:variable>

  <redirect:write select="concat($outputDir,$fnwosfx,'/',@name,'-message.html')">
    <HTML>
    <HEAD>
    <xsl:comment>Generated by wsdldoc on <xsl:value-of select="wev-ext:getDate()" /></xsl:comment>
    <TITLE>
      <xsl:value-of select="@name" />
    </TITLE>
    <LINK REL="stylesheet" TYPE="text/css" HREF="../stylesheet.css" TITLE="Style"></LINK>
    </HEAD>
    <BODY BGCOLOR="white">
    <xsl:call-template name="topNavbar">
      <xsl:with-param name="pageType" select="'message'"/>
      <xsl:with-param name="label" select="$fnwosfx"/>
    </xsl:call-template>

    <xsl:comment> ======== START OF MESSAGE DATA ======== </xsl:comment>
    <H2>
    <FONT SIZE="-1">
      <xsl:value-of select="$fnwosfx" />
    </FONT>
    <BR />
      <xsl:text>Message </xsl:text>
      <xsl:value-of select="@name"/>
    </H2>
    <P></P>
    <P></P>
    <HR />
    <DL>
    <DT>
      <xsl:text>Message </xsl:text>
    <B>
      <xsl:value-of select="@name"/>
    </B>
    </DT>
    </DL>
    <P>
    <xsl:call-template name="getDocumentation">
      <xsl:with-param name="el" select="current()"/>
    </xsl:call-template>
    </P>
    <P></P>
    <HR />
    <P></P>
    <xsl:comment> ========== PART SUMMARY =========== </xsl:comment>
    <A NAME="message_summary"> <!-- --></A>
    <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
    <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
    <TD COLSPAN="2">
    <FONT SIZE="+2">
    <B>
      <xsl:text>Part Summary</xsl:text>
    </B>
    </FONT>
    </TD>
    </TR>
      <xsl:apply-templates select="wsdl:part" mode="message-summary"/>
    </TABLE>
    <P></P>
    <xsl:comment> ============ PART DETAIL ========== </xsl:comment>
    <A NAME="message_detail"> <!-- --></A>
    <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
    <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
    <TD COLSPAN="1">
    <FONT SIZE="+2">
    <B>
      <xsl:text>Part Detail</xsl:text>
    </B>
    </FONT>
    </TD>
    </TR>
    </TABLE>
      <xsl:apply-templates select="wsdl:part" mode="message-detail"/>
    <HR />
    <xsl:comment> ========= END OF MESSAGE DATA ========= </xsl:comment>

    <xsl:call-template name="botNavbar">
      <xsl:with-param name="pageType" select="'message'"/>
      <xsl:with-param name="label" select="$fnwosfx"/>
    </xsl:call-template>
    </BODY>
    </HTML>
  </redirect:write>
  </xsl:template>

  <xsl:template match="wsdl:part" mode="message-summary">
        <xsl:variable name="partName" select="@name" />

    <TR BGCOLOR="white" CLASS="TableRowColor">
    <TD ALIGN="right" VALIGN="top" WIDTH="15%">
      <A HREF="{concat('#',generate-id())}">
        <xsl:value-of select="$partName"/>
      </A>
    </TD>
    <TD>
      <xsl:call-template name="firstSentence">
        <xsl:with-param name="el" select="current()"/>
      </xsl:call-template>
    </TD>
    </TR>
  </xsl:template>

  <xsl:template match="wsdl:part" mode="message-detail">
        <xsl:variable name="partName" select="@name" />

    <A NAME="{generate-id()}"> <!-- --></A>
    <H3>
      <xsl:value-of select="$partName" />
    </H3>
    <DL>
    <DD>
      <B>Type: </B>
      <xsl:choose>
        <xsl:when test="@element">
          <xsl:value-of select="@element"/>
        </xsl:when>
        <xsl:when test="@type">
          <xsl:value-of select="@type"/>
        </xsl:when>
      </xsl:choose>
    </DD>
    <P></P>
    <DD>
    <xsl:call-template name="getDocumentation">
      <xsl:with-param name="el" select="current()"/>
    </xsl:call-template>
    </DD>
    </DL>
    <HR />
  </xsl:template>

</xsl:stylesheet>
