<?xml version="1.0" ?>
<xsl:stylesheet 
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
        xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
        xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/" 
        xmlns:http="http://schemas.xmlsoap.org/wsdl/http/"
        exclude-result-prefixes="wsdl soap http" 
        xmlns:redirect="org.apache.xalan.xslt.extensions.Redirect"
        xmlns:wev-ext="ext1" 
        extension-element-prefixes="redirect wev-ext" 
        version="1.0">

  <xsl:template match="wsdl:service">
    <xsl:param name="file"/>

    <xsl:variable name="fname">
      <xsl:call-template name="filenameFix">
        <xsl:with-param name="wsdlFileName" select="$file"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="fnwosfx">
      <xsl:value-of select="substring-before($fname, '.wsdl')"/>
    </xsl:variable>

  <redirect:write select="concat($outputDir,$fnwosfx,'/',@name,'-service.html')">
    <HTML>
    <HEAD>
    <xsl:comment>Generated by wsdldoc on <xsl:value-of select="wev-ext:getDate()" /></xsl:comment>
    <TITLE>
      <xsl:value-of select="@name" />
    </TITLE>
    <LINK REL="stylesheet" TYPE="text/css" HREF="../stylesheet.css" TITLE="Style"></LINK>
    </HEAD>
    <BODY BGCOLOR="white">
    <xsl:call-template name="topNavbar">
      <xsl:with-param name="pageType" select="'service'"/>
      <xsl:with-param name="label" select="$fnwosfx"/>
    </xsl:call-template>

    <xsl:comment> ======== START OF SERVICE DATA ======== </xsl:comment>
    <H2>
    <FONT SIZE="-1">
      <xsl:value-of select="$fnwosfx" />
    </FONT>
    <BR />
      <xsl:text>Service </xsl:text>
      <xsl:value-of select="@name"/>
    </H2>
    <P></P>
    <P></P>
    <HR />
    <DL>
    <DT>
      <xsl:text>Service </xsl:text>
    <B>
      <xsl:value-of select="@name"/>
    </B>
    </DT>
    </DL>
    <P>
    <xsl:call-template name="getDocumentation">
      <xsl:with-param name="el" select="current()"/>
    </xsl:call-template>
    </P>
    <P></P>
    <HR />
    <P></P>
    <xsl:comment> ========== PORT SUMMARY =========== </xsl:comment>
    <A NAME="service_summary"> <!-- --></A>
    <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
    <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
    <TD COLSPAN="2">
    <FONT SIZE="+2">
    <B>
      <xsl:text>Port Summary</xsl:text>
    </B>
    </FONT>
    </TD>
    </TR>
      <xsl:apply-templates select="wsdl:port" mode="service-summary"/>
    </TABLE>
    <P></P>
    <xsl:comment> ============ PORT DETAIL ========== </xsl:comment>
    <A NAME="service_detail"> <!-- --></A>
    <TABLE BORDER="1" CELLPADDING="3" CELLSPACING="0" WIDTH="100%">
    <TR BGCOLOR="#CCCCFF" CLASS="TableHeadingColor">
    <TD COLSPAN="1">
    <FONT SIZE="+2">
    <B>
      <xsl:text>Port Detail</xsl:text>
    </B>
    </FONT>
    </TD>
    </TR>
    </TABLE>
      <xsl:apply-templates select="wsdl:port" mode="service-detail"/>
    <HR />
    <xsl:comment> ========= END OF SERVICE DATA ========= </xsl:comment>

    <xsl:call-template name="botNavbar">
      <xsl:with-param name="pageType" select="'service'"/>
      <xsl:with-param name="label" select="$fnwosfx"/>
    </xsl:call-template>
    </BODY>
    </HTML>
  </redirect:write>
  </xsl:template>

  <xsl:template match="wsdl:port" mode="service-summary">
    <xsl:variable name="portName" select="@name" />

    <TR BGCOLOR="white" CLASS="TableRowColor">
    <TD ALIGN="right" VALIGN="top" WIDTH="15%">
    <xsl:value-of select="$portName"/>
    </TD>
    <TD>
      <xsl:call-template name="firstSentence">
        <xsl:with-param name="el" select="current()"/>
      </xsl:call-template>
    </TD>
    </TR>
  </xsl:template>

  <xsl:template match="wsdl:port" mode="service-detail">

  <xsl:variable name="bndgname">
    <xsl:call-template name="makeLocal">
      <xsl:with-param name="qname" select="current()/@binding"/>
    </xsl:call-template>
  </xsl:variable>
  <xsl:variable name="bndg"
    select="../../wsdl:binding[@name=$bndgname]"/>

    <H3>
      <xsl:value-of select="@name" />
    </H3>
    <DL>
    <DD>
    <B>Binding: </B>
    <xsl:choose>
      <!-- if the wsdl:binding element is in this file... -->
      <xsl:when test="$bndg">
        <A HREF="{concat($bndg/@name,'-binding.html')}">
          <xsl:value-of select="$bndg/@name"/>
        </A>
      </xsl:when>
      <!-- 
           otherwise assume best practices and wsdl:binding
           is defined in a separate file with the naming pattern of
           this-wsdl:definitions/@name-dash-"interface".
       -->
      <xsl:otherwise>
        <xsl:variable name="lpart">
          <xsl:value-of select="substring-after(@binding,':')"/>
        </xsl:variable>
        <A HREF="{concat('../',../../@name,'/',$lpart,'-binding.html')}">
          <xsl:value-of select="@binding"/>
        </A>
      </xsl:otherwise>
    </xsl:choose>
    </DD>
    <DD>
    <xsl:choose>
      <xsl:when test="soap:address">
        <B>SOAP Address: </B>
        <xsl:value-of select="soap:address/@location"/>
      </xsl:when>
      <xsl:when test="http:address">
        <B>HTTP Address: </B>
        <xsl:value-of select="http:address/@location"/>
      </xsl:when>
    </xsl:choose>
    </DD>
    <DD>
    <P></P>
    <xsl:call-template name="getDocumentation">
      <xsl:with-param name="el" select="current()"/>
    </xsl:call-template>
    </DD>
    </DL>
    <HR />
  </xsl:template>

</xsl:stylesheet>
