<?xml version="1.0" ?>
<xsl:stylesheet 
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
        xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
        exclude-result-prefixes="wsdl" 
        xmlns:wev-ext="ext1" 
        extension-element-prefixes="wev-ext" 
        version="1.0">

  <xsl:param name="outputDir"/>
  <xsl:param name="docTitle"/>

  <xsl:output method="html" />

  <xsl:include href="wsdl-utils.xsl"/>
  <xsl:include href="build-css.xsl"/>
  <xsl:include href="build-help-doc.xsl"/>
  <xsl:include href="build-overview.xsl"/>
  <xsl:include href="build-definitions-list.xsl"/>
  <xsl:include href="build-subelement-list.xsl"/>
  <xsl:include href="build-operation-index.xsl"/>
  <xsl:include href="definitions-frame.xsl"/>
  <xsl:include href="definitions-summary.xsl"/>
  <xsl:include href="format-binding.xsl"/>
  <xsl:include href="format-message.xsl"/>
  <xsl:include href="format-porttype.xsl"/>
  <xsl:include href="format-service.xsl"/>
  <xsl:include href="format-types.xsl"/>

  <xsl:template match="/">
    <!--
    <xsl:message><xsl:text>Generating cascading style sheet...</xsl:text></xsl:message>
    -->
    <xsl:call-template name="buildCSS"/>
    <!--
    <xsl:message><xsl:text>Generating top level frame definition...</xsl:text></xsl:message>
    -->
    <xsl:call-template name="buildIndexDotHtml"/>
    <!--
    <xsl:message><xsl:text>Generating help document...</xsl:text></xsl:message>
    -->
    <xsl:call-template name="buildHelpDoc"/>
    <!--
    <xsl:message><xsl:text>Generating files overview...</xsl:text></xsl:message>
    -->
    <xsl:call-template name="buildOverview"/>
    <!--
    <xsl:message><xsl:text>Generating definitions list...</xsl:text></xsl:message>
    -->
    <xsl:call-template name="buildDefinitionsList"/>
    <!--
    <xsl:message><xsl:text>Generating sub-element list...</xsl:text></xsl:message>
    -->
    <xsl:call-template name="buildSubelementList"/>
    <!--
    <xsl:message><xsl:text>Generating operation index...</xsl:text></xsl:message>
    -->
    <xsl:call-template name="buildOperationIndex"/>
    <xsl:for-each select="/wsdlfilelist/entry">
      <xsl:apply-templates select="document(@filename)/wsdl:definitions" mode="frame">
        <xsl:with-param name="file" select="@filename"/>
      </xsl:apply-templates>
      <xsl:apply-templates select="document(@filename)/wsdl:definitions" mode="summary">
        <xsl:with-param name="file" select="@filename"/>
      </xsl:apply-templates>
      <xsl:apply-templates select="document(@filename)/wsdl:definitions">
        <xsl:with-param name="file" select="@filename"/>
      </xsl:apply-templates>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="wsdl:definitions">
    <xsl:param name="file"/>

    <xsl:variable name="fname">
      <xsl:call-template name="getName">
        <xsl:with-param name="path" select="$file"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="fnwosfx">
      <xsl:value-of select="substring-before($fname, '.wsdl')"/>
    </xsl:variable>

    <!--
    <xsl:message><xsl:text>Generating detailed documentation for </xsl:text>
      <xsl:value-of select="$fnwosfx"/><xsl:text>...</xsl:text>
    </xsl:message>
    -->

    <xsl:apply-templates select="wsdl:types">
      <xsl:with-param name="file" select="$file"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="wsdl:message">
      <xsl:with-param name="file" select="$file"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="wsdl:portType">
      <xsl:with-param name="file" select="$file"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="wsdl:binding">
      <xsl:with-param name="file" select="$file"/>
    </xsl:apply-templates>
    <xsl:apply-templates select="wsdl:service">
      <xsl:with-param name="file" select="$file"/>
    </xsl:apply-templates>
  </xsl:template>

</xsl:stylesheet>
